summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/pilotSerialDatabase.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/pilotSerialDatabase.cc')
-rw-r--r--kpilot/lib/pilotSerialDatabase.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/kpilot/lib/pilotSerialDatabase.cc b/kpilot/lib/pilotSerialDatabase.cc
index a38898d1..f57cac93 100644
--- a/kpilot/lib/pilotSerialDatabase.cc
+++ b/kpilot/lib/pilotSerialDatabase.cc
@@ -34,7 +34,7 @@
#include <pi-dlp.h>
-#include <qfile.h>
+#include <tqfile.h>
#include <klocale.h>
#include <kdebug.h>
@@ -45,7 +45,7 @@
#include "kpilotdevicelink.h"
PilotSerialDatabase::PilotSerialDatabase(KPilotDeviceLink *l,
- const QString &dbName) :
+ const TQString &dbName) :
PilotDatabase(dbName),
fDBName( dbName ),
fDBHandle(-1),
@@ -56,8 +56,8 @@ PilotSerialDatabase::PilotSerialDatabase(KPilotDeviceLink *l,
}
PilotSerialDatabase::PilotSerialDatabase( KPilotDeviceLink *l, const DBInfo *info ) :
- PilotDatabase( info ? Pilot::fromPilot( info->name ) : QString::null ),
- fDBName( QString::null ),
+ PilotDatabase( info ? Pilot::fromPilot( info->name ) : TQString::null ),
+ fDBName( TQString::null ),
fDBHandle( -1 ),
fDBSocket( l->pilotSocket() )
{
@@ -86,9 +86,9 @@ PilotSerialDatabase::~PilotSerialDatabase()
closeDatabase();
}
-QString PilotSerialDatabase::dbPathName() const
+TQString PilotSerialDatabase::dbPathName() const
{
- QString s = CSL1("Pilot:");
+ TQString s = CSL1("Pilot:");
s.append(fDBName);
return s;
}
@@ -140,10 +140,10 @@ unsigned int PilotSerialDatabase::recordCount() const
}
-// Returns a QValueList of all record ids in the database.
-QValueList<recordid_t> PilotSerialDatabase::idList()
+// Returns a TQValueList of all record ids in the database.
+TQValueList<recordid_t> PilotSerialDatabase::idList()
{
- QValueList<recordid_t> idlist;
+ TQValueList<recordid_t> idlist;
int idlen=recordCount();
if (idlen<=0) return idlist;
@@ -346,14 +346,14 @@ void PilotSerialDatabase::openDatabase()
setDBOpen(false);
- QString s = getDBName();
+ TQString s = getDBName();
if (s.isEmpty())
{
WARNINGKPILOT << "Bad DB name, " << s << " string given." << endl;
return;
}
- QCString encodedName = QFile::encodeName(s);
+ TQCString encodedName = TQFile::encodeName(s);
if (encodedName.isEmpty())
{
WARNINGKPILOT << "Bad DB name, "